package main

import (
	"fmt"
	"io"
	"locking-kit-server/consts"
	"locking-kit-server/handler"
	"locking-kit-server/utils"
	"locking-kit-server/websocket"
	"log"
	"net/http"
	"os"
	"path/filepath"
	"strconv"
	"time"
)

/**
 * @author yuanrh
 * @description 主函数
 * @date 2021/6/28 11:11
 **/

func main() {

	//日志设置
	_,err := os.Stat(consts.LOG_PATH)
	if err != nil {
		os.MkdirAll(consts.LOG_PATH, os.ModePerm)
	}
	logpath :=filepath.Join(consts.LOG_PATH,fmt.Sprintf("%v-%d.log",strconv.Itoa((time.Now().Year())),time.Now().Month()))
	logFile, err := os.OpenFile(logpath, os.O_CREATE|os.O_WRONLY|os.O_APPEND, 0644)
	if err != nil {
		log.Printf("open log file failed, err:", err)
		return
	}
	multiWriter := io.MultiWriter(os.Stdout,logFile)
	log.SetOutput(multiWriter)
	log.SetPrefix(consts.LOG_PREFIX)
	log.SetFlags(log.Ldate | log.Ltime | log.Lshortfile)

	utils.InitWorker(101)

	//http://localhost:7777/ws
	http.HandleFunc("/api/syncFolderToWorkSpace", handler.SyncFolderToWorkSpace)
	http.HandleFunc("/api/downloadFile", handler.DownloadFile)
	http.HandleFunc("/websocket/subscriptionTaskSync", websocket.SubscriptionTaskSyncHandler)

	//服务端启动
	log.Println("服务启动成功，监听端口7888，等待连接...")
	http.ListenAndServe("127.0.0.1:7888", nil)

}

